Crate yarn

Crate yarn 

A simple PostgreSQL-based task runner.

Structs

Worker
A worker that checks for new tasks and runs them.

Enums

SubmitError
Errors that may occur when submitting or scheduling tasks.

Constants

NOTIFY_PG_CHANNEL
The name of the PostgreSQL notification channel used to signal that there are new tasks.

Traits

Task
Task types that can be stored in the database and run later.
TaskError
An error that can say whether it should be considered permanent or transient.
TaskExt
Additional functionality for Task types. Used for submitting and scheduling tasks (i.e. inserting in the database) or fetching tasks from the database.

Functions

run_migrations
Run any pending database migrations for the yarn schema, which handles the storage of tasks.