A simple PostgreSQL-based task runner.
Structs
- Worker
- A worker that checks for new tasks and runs them.
Enums
- Submit
Error - Errors that may occur when submitting or scheduling tasks.
Constants
- NOTIFY_
PG_ CHANNEL - The name of the PostgreSQL notification channel used to signal that there are new tasks.
Traits
- Task
- Task types that can be stored in the database and run later.
- Task
Error - An error that can say whether it should be considered permanent or transient.
- TaskExt
- Additional functionality for
Tasktypes. Used for submitting and scheduling tasks (i.e. inserting in the database) or fetching tasks from the database.
Functions
- run_
migrations - Run any pending database migrations for the
yarnschema, which handles the storage of tasks.